==> ToolChain_STM32_1.0.27.tar.bz: ToolChain_STM32/Examples/example_leds.h <==
#ifndef EXAMPLE_LEDS
#define EXAMPLE_LEDS

/*{ EsampleLeds::.h ************************************************
 
 Empty template for new header files.
 Copy and adapt to your needs.
 
}*/
//{ Includes *************************************************************

// Basic set of helper functions
#include "stm32_io.h"
#include <stdlib.h>

#define USE_STDPERIPH_DRIVER
#include "stm32f10x.h"
#include "core_cm3.h"        // StdPeripheralsLibrary/CMSIS/CM3/CoreSupport/
#include "stm32f10x_conf.h"

/*{ optional
// ADC
#include "stm32f10x_adc.h"
#include "stm32f10x_dma.h"

// Timers
#include "stm32f10x_tim.h"

#include "stm32f10x_it.h"
#include "system_stm32f10x.h"
}*/

#include "bits.h"

#include <string.h>
#include "FreeRTOS.h"
#include "task.h"

//} Includes
//{ Defines/ TypeDefs ****************************************************

#define PB_LED1   GPIOC, 6    // status led 1 on Olimex proto board P107

//} Defines
//{ Structures/ Enums ****************************************************

typedef struct {
  GPIO_TypeDef* GPIOx;   // which port to use for LED
  u32_t Pin;             //
  u16_t OnPeriod;        //  on time of LED1 (usecs)
  u16_t OffPeriod;       // off time of LED1 (usecs)
} ConfigLED_t;

//} Structures/ Enums
//{ Structures/ Enums ****************************************************

//} Structures/ Enums
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

// basic hardware intialization
void leds_initPorts();

// main entry: initializes hardware + spawns all threads
// returns immediately
void leds_start();

// task: changes brightness continuosly
void taskBrightness(void *pvParameters);

// task: applies brightness to LEDs
void taskControlLed(void *pvParameters);

//} Function prototypes

#endif //EXAMPLE_LEDS

==> ToolChain_STM32_1.0.31.tar.bz: ToolChain_STM32/Examples/example_leds.h <==
#ifndef EXAMPLE_LEDS
#define EXAMPLE_LEDS

/*{ EsampleLeds::.h ************************************************
 
 Empty template for new header files.
 Copy and adapt to your needs.
 
}*/
//{ Includes *************************************************************

// Basic set of helper functions
#include "stm32_io.h"
#include <stdlib.h>

#define USE_STDPERIPH_DRIVER
#include "stm32f10x.h"
#include "core_cm3.h"        // StdPeripheralsLibrary/CMSIS/CM3/CoreSupport/
#include "stm32f10x_conf.h"
#include "bits.h"
#include <string.h>
#include "FreeRTOS.h"
#include "stm32f10x_rcc.h"
#include "task.h"

//} Includes
//{ Defines/ TypeDefs ****************************************************

#ifndef PB_LED1
  //X#define PB_LED1   GPIOC, 6    // status led 1 on Olimex proto board P107
  #error PB_LED1 not defined!
#endif
#ifndef PB_LED2
  #error PB_LED2 not defined!
  //X #define PB_LED2   GPIOC, 7    // status led 1 on Olimex proto board P107
#endif

//} Defines
//{ Structures/ Enums ****************************************************

typedef struct {
  GPIO_TypeDef* GPIOx;   // which port to use for LED
  u32_t Pin;             //
  u16_t OnPeriod;        //  on time of LED1 (usecs)
  u16_t OffPeriod;       // off time of LED1 (usecs)
} ConfigLED_t;

//} Structures/ Enums
//{ Structures/ Enums ****************************************************

//} Structures/ Enums
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

/** loads GPIO + Pin into given structure
 * ConfigLED
 * GPIOx      one of GPIOA, GPIOB, GPIOC, GPIOD
 * Pin        pin number on given GPIOx
 *
 *
 */
ConfigLED_t* setLedGPIO(ConfigLED_t* ConfigLED, GPIO_TypeDef* GPIOx, u32_t Pin);

// basic hardware intialization
void leds_initPorts();

// main entry: initializes hardware + spawns all threads
// returns immediately
void leds_start();

// task: changes brightness continuosly
void taskBrightness(void *pvParameters);

// task: applies brightness to LEDs
void taskControlLed(void *pvParameters);

//} Function prototypes

#endif //EXAMPLE_LEDS
